CompiledRynaExpr

Enum CompiledRynaExpr 

pub enum CompiledRynaExpr {
Show 108 variants Empty, Bool(bool), Int(Integer), Float(f64), Str(String), Array(usize, Type), Lambda(usize, usize, Type, Type), Construct(usize, usize, Vec<Type>), AttributeAssign(usize), AttributeMove(usize), AttributeRef(usize), AttributeMut(usize), AttributeCopy(usize), AttributeDeref(usize), Tuple(usize), TupleElemMove(usize), TupleElemRef(usize), TupleElemMut(usize), TupleElemCopy(usize), TupleElemDeref(usize), IdxMove, IdxRef, IdxMut, IdxMoveRef, StoreIntVariable(usize, bool, Integer), StoreBoolVariable(usize, bool, bool), StoreFloatVariable(usize, bool, f64), StoreStringVariable(usize, bool, String), StoreVariable(usize, bool), GetVariable(usize, bool), CloneVariable(usize, bool), RefVariable(usize, bool), DerefVariable(usize, bool), CopyVariable(usize, bool), MoveVariable(usize, bool), Assign, AssignToVar(usize, bool), AssignToVarDirect(usize, bool), Drop, Jump(usize), RelativeJump(i32), RelativeJumpIfFalse(usize, bool), RelativeJumpIfTrue(usize, bool), Call(usize), CallDestructor(usize), DeleteVar(usize, bool), LambdaCall, LambdaCallRef, Return, NativeFunctionCall(usize, usize, Vec<Type>), UnaryOperatorCall(usize, usize, Vec<Type>), BinaryOperatorCall(usize, usize, Vec<Type>), NaryOperatorCall(usize, usize, Vec<Type>), NativeFunctionCallNoRet(usize, usize, Vec<Type>), UnaryOperatorCallNoRet(usize, usize, Vec<Type>), BinaryOperatorCallNoRet(usize, usize, Vec<Type>), Ref, Mut, Copy, Deref, Demut, Move, ToFloat, Inc, Dec, Addi, Addf, Subi, Subf, Muli, Mulf, Divi, Divf, Modi, Modf, Negi, Negf, AddStr, NotB, AndB, OrB, XorB, Shr, Shl, Lti, Ltf, Gti, Gtf, Lteqi, Lteqf, Gteqi, Gteqf, Eqi, Eqf, Neqi, Neqf, EqBool, NeqBool, EqStr, NeqStr, Not, Or, And, Xor, Nand, Nor, Placeholder(PlaceholderType), Halt,
}

Variants



Empty



Bool(bool)



Int(Integer)



Float(f64)



Str(String)



Array(usize, Type)



Lambda(usize, usize, Type, Type)



Construct(usize, usize, Vec<Type>)



AttributeAssign(usize)



AttributeMove(usize)



AttributeRef(usize)



AttributeMut(usize)



AttributeCopy(usize)



AttributeDeref(usize)



Tuple(usize)



TupleElemMove(usize)



TupleElemRef(usize)



TupleElemMut(usize)



TupleElemCopy(usize)



TupleElemDeref(usize)



IdxMove



IdxRef



IdxMut



IdxMoveRef



StoreIntVariable(usize, bool, Integer)



StoreBoolVariable(usize, bool, bool)



StoreFloatVariable(usize, bool, f64)



StoreStringVariable(usize, bool, String)



StoreVariable(usize, bool)



GetVariable(usize, bool)



CloneVariable(usize, bool)



RefVariable(usize, bool)



DerefVariable(usize, bool)



CopyVariable(usize, bool)



MoveVariable(usize, bool)



Assign



AssignToVar(usize, bool)



AssignToVarDirect(usize, bool)



Drop



Jump(usize)



RelativeJump(i32)



RelativeJumpIfFalse(usize, bool)



RelativeJumpIfTrue(usize, bool)



Call(usize)



CallDestructor(usize)



DeleteVar(usize, bool)



LambdaCall



LambdaCallRef



Return



NativeFunctionCall(usize, usize, Vec<Type>)



UnaryOperatorCall(usize, usize, Vec<Type>)



BinaryOperatorCall(usize, usize, Vec<Type>)



NaryOperatorCall(usize, usize, Vec<Type>)



NativeFunctionCallNoRet(usize, usize, Vec<Type>)



UnaryOperatorCallNoRet(usize, usize, Vec<Type>)



BinaryOperatorCallNoRet(usize, usize, Vec<Type>)



Ref



Mut



Copy



Deref



Demut



Move



ToFloat



Inc



Dec



Addi



Addf



Subi



Subf



Muli



Mulf



Divi



Divf



Modi



Modf



Negi



Negf



AddStr



NotB



AndB



OrB



XorB



Shr



Shl



Lti



Ltf



Gti



Gtf



Lteqi



Lteqf



Gteqi



Gteqf



Eqi



Eqf



Neqi



Neqf



EqBool



NeqBool



EqStr



NeqStr



Not



Or



And



Xor



Nand



Nor



Placeholder(PlaceholderType)



Halt

Implementations

Source

impl CompiledRynaExpr

pub fn needs_float(&self) -> bool

pub fn needs_deref(&self) -> bool

pub fn needs_no_drop(&self) -> bool

pub fn to_string(&self, ctx: &RynaContext) -> String